package java.awt;

import java.awt.geom.Rectangle2D;
import java.awt.image.ColorModel;
import java.beans.ConstructorProperties;
import java.awt.geom.AffineTransform;
import java.awt.geom.Point2D;

public final class LinearGradientPaint extends MultipleGradientPaint
{
    private final Point2D start;
    private final Point2D end;
    
    public LinearGradientPaint(float x, float y, float x2, float y2, float[] array, Color[] array2) {
        this(new Point2D.Float(x, y), new Point2D.Float(x2, y2), array, array2, MultipleGradientPaint.CycleMethod.NO_CYCLE);
    }
    
    public LinearGradientPaint(float x, float y, float x2, float y2, float[] array, Color[] array2, MultipleGradientPaint.CycleMethod cycleMethod) {
        this(new Point2D.Float(x, y), new Point2D.Float(x2, y2), array, array2, cycleMethod);
    }
    
    public LinearGradientPaint(Point2D point2D, Point2D point2D2, float[] array, Color[] array2) {
        this(point2D, point2D2, array, array2, MultipleGradientPaint.CycleMethod.NO_CYCLE);
    }
    
    public LinearGradientPaint(Point2D point2D, Point2D point2D2, float[] array, Color[] array2, MultipleGradientPaint.CycleMethod cycleMethod) {
        this(point2D, point2D2, array, array2, cycleMethod, MultipleGradientPaint.ColorSpaceType.SRGB, new AffineTransform());
    }
    
    @ConstructorProperties({ "startPoint", "endPoint", "fractions", "colors", "cycleMethod", "colorSpace", "transform" })
    public LinearGradientPaint(Point2D point2D, Point2D obj, float[] array, Color[] array2, MultipleGradientPaint.CycleMethod cycleMethod, MultipleGradientPaint.ColorSpaceType colorSpaceType, AffineTransform affineTransform) {
        super(array, array2, cycleMethod, colorSpaceType, affineTransform);
        if (point2D == null || obj == null) {
            throw new NullPointerException("Start and end points must benon-null");
        }
        if (point2D.equals(obj)) {
            throw new IllegalArgumentException("Start point cannot equalendpoint");
        }
        this.start = new Point2D.Double(point2D.getX(), point2D.getY());
        this.end = new Point2D.Double(obj.getX(), obj.getY());
        return;
    }
    
    @Override
    public PaintContext createContext(ColorModel colorModel, Rectangle rectangle, Rectangle2D rectangle2D, AffineTransform tx, RenderingHints renderingHints) {
        tx = new AffineTransform(tx);
        tx.concatenate(this.gradientTransform);
        if (this.fractions.length == 2 && this.cycleMethod != MultipleGradientPaint.CycleMethod.REPEAT && this.colorSpace == MultipleGradientPaint.ColorSpaceType.SRGB) {
            return new GradientPaintContext(colorModel, this.start, this.end, tx, this.colors[0], this.colors[1], this.cycleMethod != MultipleGradientPaint.CycleMethod.NO_CYCLE);
        }
        return new LinearGradientPaintContext(this, colorModel, rectangle, rectangle2D, tx, renderingHints, this.start, this.end, this.fractions, this.colors, this.cycleMethod, this.colorSpace);
    }
    
    public Point2D getStartPoint() {
        return new Point2D.Double(this.start.getX(), this.start.getY());
    }
    
    public Point2D getEndPoint() {
        return new Point2D.Double(this.end.getX(), this.end.getY());
    }
}
